@@ -158,6 +158,13 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         payee = self.wrapper.payee
         self.assertEqual(payee.organisation_unit_number, '003701999207')
 
+    def test_payee_organisation_taxcode(self):
+        """
+        test_payee_contact_phone
+        """
+        payee = self.wrapper.payee
+        self.assertEqual(payee.organisation_taxcode, '0199920-7')
+
     def test_payee_bank_accounts(self):
         """
         test_payee_contact_phone
@@ -209,7 +216,7 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
 
         """
         payer = self.wrapper.payer
-        self.assertEqual(str(payer.business_id), '')
+        self.assertEqual(str(payer.business_id), '1234567-1')
 
     def test_payer_address(self):
         """
@@ -245,7 +252,7 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         test_payer_customer_number
         """
         payer = self.wrapper.payer
-        self.assertEqual(payer.customer_number, '0123456-7')
+        self.assertEqual(payer.customer_number, '1122')
 
     def test_payer_contact_phone(self):
         """
@@ -261,7 +268,15 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
 
         """
         payer = self.wrapper.payer
-        self.assertEqual(str(payer.organisation_unit_number), '003701234567')
+        self.assertEqual(str(payer.organisation_unit_number), '00371234567')
+
+    def test_payer_organisation_taxcode(self):
+        """
+        test_payer_contact_phone
+
+        """
+        payer = self.wrapper.payer
+        self.assertEqual(str(payer.organisation_taxcode), 'FI12345671')
 
     def test_invoice_total_taxed(self):
         """
@@ -551,7 +566,7 @@ class TestFinvoiceWrapperWithPankkiyhdistysFinvoice(FinvoiceTestCase):
 
         """
         payee = self.wrapper.payee
-        self.assertEqual(payee.business_id, None)
+        self.assertEqual(payee.business_id, '')
 
     def test_payer_name(self):
         """
