@@ -251,7 +251,7 @@ class BankAccount(object):
 
 class Payee(object):
     name = ''
-    business_id = None
+    business_id = ''
     postal_address = ''
     net_service_id = ''
     bank_account_number = ''
@@ -263,6 +263,7 @@ class Payee(object):
     phone = ''
     website = ''
     organisation_unit_number = ''
+    organisation_taxcode = ''
     bank_accounts = None
 
     def __init__(self, doc, envelope=None):
@@ -307,6 +308,16 @@ class Payee(object):
                 acc = BankAccount(account_number, swift_code)
                 self.bank_accounts.append(acc)
 
+        org_unit_number = doc.SellerOrganisationUnitNumberSet
+        if len(org_unit_number) > 0:
+            self.organisation_unit_number = org_unit_number[0].text
+            if not self.business_id \
+                and self.organisation_unit_number.startswith('0037') \
+                    and len(self.organisation_unit_number) > 11:
+                        business_id = self.organisation_unit_number[4:12]
+                        if BusinessID.is_valid(business_id):
+                            self.business_id = business_id
+
         details = doc.SellerPartyDetailsSet
         if len(details) > 0:
             postal_address = details[0].SellerPostalAddressDetailsSet
@@ -316,9 +327,17 @@ class Payee(object):
             if len(self.name) < 1 and len(seller) > 0:
                 self.name = seller[0].text
 
+            taxcode = details[0].SellerOrganisationTaxCodeSet
+            if len(taxcode) > 0:
+                self.organisation_taxcode = taxcode[0].text
+                if not self.business_id:
+                    if BusinessID.is_valid(taxcode[0].text):
+                        self.business_id = str(BusinessID(taxcode[0].text))
+
             business_id = details[0].SellerPartyIdentifierSet
-            if not self.business_id and len(business_id) > 0:
-                self.business_id = business_id[0].text
+            if not self.business_id and len(business_id) > 0 and \
+                    business_id[0].text:
+                self.business_id = str(business_id[0].text)
 
         contact_name = doc.SellerContactPersonNameSet
         if len(contact_name) > 0:
@@ -333,15 +352,6 @@ class Payee(object):
             if len(email) > 0:
                 self.contact_email = email[0].text
 
-        org_unit_number = doc.SellerOrganisationUnitNumberSet
-        if len(org_unit_number) > 0:
-            self.organisation_unit_number = org_unit_number[0].text
-            if not self.business_id \
-                and self.organisation_unit_number.startswith('0037') \
-                    and len(self.organisation_unit_number) > 11:
-                        business_id = self.organisation_unit_number[4:12]
-                        if BusinessID.is_valid(business_id):
-                            self.business_id = business_id
 
 
 class Payer(object):
@@ -360,6 +370,7 @@ class Payer(object):
     phone = ''
     #website = ''
     organisation_unit_number = ''
+    organisation_taxcode = ''
 
     def __init__(self, doc=None, envelope=None):
         self.net_service_id = ''
@@ -368,14 +379,36 @@ class Payer(object):
         if envelope:
             self.net_service_id = envelope.buyer_id
 
+        org_unit_number = doc.BuyerOrganisationUnitNumberSet
+        if len(org_unit_number) > 0 and org_unit_number[0].text:
+            self.organisation_unit_number = org_unit_number[0].text
+            if len(self.business_id)==0 \
+                and self.organisation_unit_number.startswith('0037') \
+                    and len(self.organisation_unit_number) > 10:
+
+                business_id = self.organisation_unit_number[4:12]
+                if BusinessID.is_valid(business_id):
+                    self.business_id = business_id
+
         details = doc.BuyerPartyDetailsSet
         if len(details) > 0:
             self.name = \
                 details[0].BuyerOrganisationNameSet.as_string(delim=' ')
-            self.customer_number = \
-                details[0].BuyerPartyIdentifierSet.as_string(delim=' ')
-            if BusinessID.is_valid(self.customer_number):
-                self.business_id = self.customer_number
+            customer_number = details[0].BuyerPartyIdentifierSet
+            if len(customer_number)>0 and customer_number[0].text:
+                self.customer_number = customer_number[0].text
+
+            taxcode = details[0].BuyerOrganisationTaxCodeSet
+            if len(taxcode) > 0 and taxcode[0].text:
+                self.organisation_taxcode = str(taxcode[0].text)
+                if len(self.business_id)==0:
+                    if BusinessID.is_valid(self.organisation_taxcode):
+                        self.business_id = \
+                            str(BusinessID(self.organisation_taxcode))
+
+            if len(self.business_id)==0 and self.customer_number:
+                if BusinessID.is_valid(self.customer_number):
+                    self.business_id = self.customer_number
 
             address_details = details[0].BuyerPostalAddressDetailsSet
             if len(address_details) > 0:
@@ -386,16 +419,6 @@ class Payer(object):
         if len(contact_name) > 0:
             self.contact_name = contact_name[0].text
 
-        org_unit_number = doc.BuyerOrganisationUnitNumberSet
-        if len(org_unit_number) > 0:
-            self.organisation_unit_number = org_unit_number[0].text
-            if len(self.business_id) < 1 \
-                and self.organisation_unit_number.startswith('0037') \
-                    and len(self.organisation_unit_number) > 11:
-                        business_id = self.organisation_unit_number[4:12]
-                        if BusinessID.is_valid(business_id):
-                            self.business_id = business_id
-
         comm_details = doc.BuyerCommunicationDetailsSet
         if len(comm_details) > 0:
             phone = comm_details[0].BuyerPhoneNumberIdentifierSet
@@ -456,33 +479,42 @@ class Row(object):
             self.unit_code = '\n'.join(unit_codes)
 
         unit_price = row.UnitPriceAmountSet
-        if len(unit_price) > 0:
-            self.unit_price = _Decimal(unit_price[0].text)
-            currency = \
-                unit_price[0].attributes.get('amountcurrencyidentifier', '')
-            self.unit_price_currency = currency
+        if len(unit_price) > 0 and unit_price[0]:
+            _unit_price = str(unit_price[0].text).strip()
+            if len(_unit_price)>0:
+                self.unit_price = _Decimal(_unit_price)
+                currency = \
+                    unit_price[0].attributes.get('amountcurrencyidentifier', '')
+                self.unit_price_currency = currency
 
         total_taxed = row.RowAmountSet
-        if len(total_taxed) > 0:
-            self.total_taxed = _Decimal(total_taxed[0].text)
-            currency = \
-                total_taxed[0].attributes.get('amountcurrencyidentifier', '')
-            self.total_taxed_currency = currency
+        if len(total_taxed) > 0 and total_taxed[0].text:
+            _total_taxed = str(total_taxed[0].text).strip()
+            if len(_total_taxed)>0:
+                self.total_taxed = _Decimal(_total_taxed)
+                currency = \
+                    total_taxed[0].attributes.get('amountcurrencyidentifier',
+                                                  '')
+                self.total_taxed_currency = currency
 
         total_untaxed = row.RowVatExcludedAmountSet
-        if len(total_untaxed) > 0:
-            total_untaxed = total_untaxed[0]
-            self.total_untaxed = _Decimal(total_untaxed.text)
-            currency = \
-                total_untaxed.attributes.get('amountcurrencyidentifier', '')
-            self.total_untaxed_currency = currency
+        if len(total_untaxed) > 0 and total_untaxed[0].text:
+            _total_untaxed = str(total_untaxed[0].text).strip()
+            if len(_total_untaxed)>0:
+                self.total_untaxed = _Decimal(_total_untaxed)
+                currency = \
+                    total_untaxed[0].attributes.get(
+                    'amountcurrencyidentifier', '')
+                self.total_untaxed_currency = currency
 
         vat_amount = row.RowVatAmountSet
-        if len(vat_amount):
-            self.vat_amount = _Decimal(vat_amount[0].text)
-            currency = \
-                vat_amount[0].attributes.get('amountcurrencyidentifier', '')
-            self.vat_amount_currency = currency
+        if len(vat_amount) and vat_amount[0].text:
+            _vat_amount = str(vat_amount[0].text).strip()
+            if len(_vat_amount)>0:
+                self.vat_amount = _Decimal(_vat_amount)
+                currency = \
+                    vat_amount[0].attributes.get('amountcurrencyidentifier', '')
+                self.vat_amount_currency = currency
 
         vat_percent = row.RowVatRatePercentSet
         if len(vat_percent) > 0:
